##########################################################################
#                                                                        #
#  This file is part of GeneSyst.                                        #
#                                                                        #
#  Copyright (C) 2004-2009                                               #
#    CNRS (Centre National de la Recherche Scientifique)                 #
#    INSA (Institut National des Sciences Appliquees)                    #
#                                                                        #
#  you can redistribute it and/or modify it under the terms of the       #
#  CeCILL License (for Ce[a] C[nrs] I[nria] L[logiciel] L[ibre]),        #
#  version 2.                                                            #
#                                                                        #
#  It is distributed in the hope that it will be useful,                 #
#  but WITHOUT ANY WARRANTY; without even the implied warranty of        #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          #
#  CeCILL License for more details. The license is provided in           #
#  french and in english in the Licences directory.                      #
##########################################################################

#!/bin/bash
#=====================================================================#
#                                                                     #
# Configuration Script of GeneSyst                                    #
#    Version : 2.4 du 21 avril 2009                                   #
#    Author  : Nicolas Stouls (nicolas.stouls@insa-lyon.fr)           #
#    Script under the CeCILL-2 license                                #
#                                                                     #
# Historique des versions :                                           #
#    Mise sous SVN                                                    #
#    Version courante : $Revision: 58 $ / $Date: 2011-06-22 17:06:04 +0200 (mer. 22 juin 2011) $
#    2.5 du 19 mai 2009                                               #
#       Correction de la ligne de commande gnre pour le GUI        #
#    2.4 du 21 avril 2009                                             #
#       GeneSyst est maintenant diffus en JAR                        #
#    2.3 du 30 aout 2007                                              #
#       Prise en compte des tactiques interactives                    #
#    2.2 du 17 avril 2007                                             #
#       Gnration d'un script de lancement GeneSyst                  #
#    2.1 du 11 mars 2007                                              #
#    2.2 du 17 avril 2007                                             #
#       Et que le dossier Class est bien prsent au mme niveau       #
#    2.0 du 20 fvrier 2007                                           #
#       Refonte totale de la prsentation et aide  la configuration  #
#    1.5 du 04 novembre 2005                                          #
#       Prise en charge de l'outil B4free en plus de l'atelierB       #
#    1.4 du 17 juin 2005                                              #
#       Mise en place de la nouvelle licence CeCILL V2                #
#    1.3.2 du 16 mai 2005                                             #
#       ajout de la variable Cst_FaireExistentielle                   #
#       retrait des tiquettes final (sinon il faut tout recompiler)  #
#                                                                     #
#    1.3.1 du 9 novembre 2004                                         #
#       Changement de shell d'excution de zsh en sh                  #
#                                                                     #
#    1.3 du 17 aout 2004                                              #
#       Le rsultat sera toujours dans un dossier.                    #
#       Ajout de la recherche de l'application dot                    #
#       Ajout de protections contre le retour  la ligne seul comme   #
#       rponse                                                       #
#                                                                     #
#    1.2 du 22 juillet 2004                                           #
#       Ajout du nom du dossier contenant le rsultat sous forme de   #
#       page web dynamique.                                           #
#                                                                     #
#    1.1 du 13 juillet 2004                                           #
#       Ajout de la vrification du contrat de licence CeCILL         #
#                                                                     #
#    1.0 du 6 fvrier 2004                                            #
#       Cration de ce script                                         #
#                                                                     #
#=====================================================================#



MessageErreur() {
  echo ""
  echo "##################"
  echo "# ERROR."
  echo "#"
  echo "#   $1"
  echo "#   $2"
  echo "#   $3"
  echo "#   $4"
  echo "#"
  echo "#   INSTALLATION ABORTED"
  echo "#"
  echo "##################"
  echo ""
  echo ""
  exit 
}

#====================================================================
# $1 : Pose la question prcise en premier paramtre .
# $2 : Le choix par dfaut est obligatoire et donn en second paramtre.
# Result : La rponse est stocke dans la variable global REPONSE.
#
PoseQuestion() {
	question="$1"
	default="$2"
	REPONSE=""
  if [ -n "${default}" ] ; then
    echo "${question} [${default}] ? " | tr -d '\012'
  else 
    echo "${question} ? " | tr -d '\012'
  fi
	read answer
	if [ "${answer}" ] ; then
    REPONSE=${answer}
	else
    REPONSE=${default}
	fi
}
#
#====================================================================


#====================================================================
# Oprations ConfigureAB et ConfigureBFF:
#
#   Paramtres :  
#     $1 : Le chemin du dossier bdb
#   Etat final : 
#     $DossierBDB : contient le chemin du dossier bdb
#     $Adressebbatch : contient le chemin du script bbatch
#     $FichierConfig : contient le chemin du fichier de configuration .rc
#
ConfigureAB(){
  # ex: 
  #/h3/nephtys/lsr/vasco/atelierb/AB/press/bdb/
  #/h3/nephtys/lsr/vasco/atelierb/AB/bin/bbatch
  #/h3/nephtys/lsr/vasco/atelierb/AB/AtelierB
  
  ConfigureBDB "$1"
  Configurebbatch `echo "$DossierBDB" | sed "s/AB\/press\/bdb\/$/AB\/bbin\/linux\/bbatch/"` \
                  `echo "$DossierBDB" | sed "s/AB\/press\/bdb\/$/AB\/bbin\/sun5.5.1\/bbatch/"` \
                  `echo "$DossierBDB" | sed "s/AB\/press\/bdb\/$/AB\/bbin\/sun5.6\/bbatch/"`
  ConfigureFichierConfig `echo "$DossierBDB" | sed "s/AB\/press\/bdb\/$/AB\/AtelierB/"` "/AB/AtelierB$"
}
#
#
ConfigureBFF(){
  # ex: 
  #/usr/local/src/B4free-V2.0/bdb/
  #/usr/local/src/B4free-V2.0/bbatch
  #/usr/local/src/B4free-V2.0/B4free.rc
  
  ConfigureBDB "$1"
  Configurebbatch `echo "$DossierBDB" | sed "s/bdb\/$/bbatch/"`
  ConfigureFichierConfig `echo "$DossierBDB" | sed "s/bdb\/$/B4free.rc/"` "/B4free.rc$"
}
#====================================================================


#====================================================================
# Oprations ConfigureBDB, Configurebbatch et ConfigureFichierConfig.
# Utilises dans le cadre de la configuration du prouveur
#
ConfigureBDB(){
  # On rajoute le slash final si ncessaire
  DossierBDB=`echo "$1/" | sed "s/\/\/$/\/$/"`
  #
  # si un choix est propos et qu'il semble bon on le conserve.
  # Sinon, une saisie par l'utilisateur est attendue
  if [ -z $DossierBDB ] || [ ! -d "$DossierBDB" ] || [ -z `echo $DossierBDB | grep '/bdb/$'` ] ; then 
  
    if [ -n "$1" ] ; then echo "" ; echo "The chosen path is not correct ($1)" ; echo "" ; fi
    
    PoseQuestion "Please enter the path ot the bdb directory" ""
    
    if [ -z $REPONSE ] || [ ! -d "$REPONSE" ] || [ -z `echo $REPONSE | grep '/bdb'` ] ; then MessageErreur "" "Incorrect path" ; fi
    #
    # On rajoute le slash final si ncessaire
    DossierBDB=`echo "$REPONSE/" | sed "s/\/\/$/\/$/"`
  fi
}
#
#
#
#
Configurebbatch(){
  # si un choix est propos et qu'il semble bon on le conserve.
  if [ -n $1 ] && [ -x "$1" ] && [ -n `echo $1 | grep '/bbatch$'` ] ; then 
    Adressebbatch=$1
  elif [ -n $2 ] && [ -x "$2" ] && [ -n `echo $2 | grep '/bbatch$'` ] ; then 
    Adressebbatch=$2
  elif [ -n $3 ] && [ -x "$3" ] && [ -n `echo $3 | grep '/bbatch$'` ] ; then 
    Adressebbatch=$3
  else
  # Sinon, une saisie par l'utilisateur est attendue
    PoseQuestion "Please enter the path to the bbatch file" ""
    if [ ! -x $REPONSE ] || [ -z $REPONSE ] ; then MessageErreur "" "Incorrect path" ; fi
    Adressebbatch=$REPONSE
  fi
}
#
#
#
#
ConfigureFichierConfig(){
  # si un choix est propos et qu'il semble bon on le conserve.
  if [ -n $1 ] && [ -f "$1" ] && [ -n `echo $1 | grep '$2'` ] ; then 
    FichierConfig=$1;
  else
  # Sinon, une saisie par l'utilisateur est attendue
    PoseQuestion "Please enter the path to the configuration file (..)$2" ""
    if [ -n $REPONSE ] && [ -f "$REPONSE" ] && [ -n `echo $REPONSE | grep '$2'` ] ; then MessageErreur "" "Incorrect path" ; fi
    FichierConfig=$REPONSE
  fi
}
#====================================================================




#====================================================================
# Vrification de l'acceptation des termes de la licence CeCILL
# -------------------------------------------------------------
#
if [ ! -e "Licences/Licence_CeCILL_V2-fr.txt" ] ; then 
  MessageErreur "" \
                "You  are not in the right folder." \
                "Please launch this script from the GeneSyst directory."
fi

more Licences/Licence_CeCILL_V2-fr.txt

echo ""
echo ""
echo ""
echo ""
echo "  This software is under the CeCILL-2 french license (close the the GPL license)."
echo "  The terms of the license can be read in:"
echo "    * Licences/Licence_CeCILL_V2-fr.html"
echo "    * Licences/Licence_CeCILL_V2-en.html"
echo ""
PoseQuestion "  Do you accept the terms of the license ? (Y/N)" "Y"
#
echo ""

if [ "y" != $REPONSE ] && [ "Y" != $REPONSE ] ; then  MessageErreur "" "License rejected." ; fi
#
# FIN de Vrification de l'acceptation des termes de la licence CeCILL
#====================================================================









#====================================================================
# Vrification de l'environnement d'excution du script
#
#if [ -z `echo $CLASSPATH | grep -i GeneSyst` ] ; then 
#  MessageErreur "La variable d'environnement CLASSPATH doit tre dfinie avant le lancement de"\
#                "ce script. Voici un exemple en bash :" \
#		""\
#		"  export CLASSPATH=\"\$CLASSPATH:`pwd`/Class/:`pwd`/Class/GUI/.:`pwd`/Class/Grappa/.\""
#fi
#
# FIN de Vrification de l'environnement d'excution du script
#====================================================================






#====================================================================
# Rcupration des informations du prouveur
# -----------------------------------------
#
# Choix par dfaut qui sera utilis pour le choix du prouveur
Def=2 
#
# Construction de la liste des installations trouves de l'AtelierB
echo ""
echo "Looking for installs of AtelierB: "
InstallationsAB=`locate "AB/press/bdb" | grep press/bdb$`
PremierAB=1
DernierAB=0
for i in $InstallationsAB ; do
  DernierAB=`expr $DernierAB + 1`
  tmp=`echo "$i" | sed "s/press\/bdb$//"`
  echo "   $DernierAB) $tmp"
  Def=$DernierAB
done
#
DernierAB=`expr $DernierAB + 1`
echo "   $DernierAB) Other install of AtelierB"
#
#
#
#
# Construction de la liste des installations trouves de B4free
echo ""
echo "Looking for install of B4free : "
InstallationsBFourFree=`locate bdb | grep /bdb$ | grep -i B4free`
PremierBFF=1
DernierBFF=0
for i in $InstallationsBFourFree ; do
  DernierBFF=`expr $DernierBFF + 1`
  tmp=`echo "$i" | sed "s/bdb$//"`
  echo "   `expr $DernierBFF + $DernierAB`) $tmp"
  Def=`expr $DernierBFF + $DernierAB`
done
#
DernierBFF=`expr $DernierBFF + 1`
echo "   `expr $DernierBFF + $DernierAB`) Other install of B4free"
#
#
#
#
# Demande de son choix  l'utilisateur
echo ""
echo "Info :"
echo "  If an install of B4Free or AtelierB has not been found, we propose you"
echo "  to stop this script and to relaunch it after executing 'sudo updatedb'."
echo ""
PoseQuestion "Which prover would you use ? (1..`expr $DernierAB + $DernierBFF`)" $Def

r=`expr $REPONSE - 1`
REPONSEbff=`expr $REPONSE - $DernierAB`
rbff=`expr $REPONSE - $DernierAB - 1`

if [ $REPONSE -ge $PremierAB ] && [ $REPONSE -lt $DernierAB ] ; then  

  j=0
  for i in $InstallationsAB ; do
    if [ $j -eq $r ] ; then k="$i" ; fi
    j=`expr $j + 1`
  done

  ConfigureAB "$k"
#  ConfigureAB "${InstallationsAB[$r]}"

elif [ $REPONSE -eq $DernierAB ] ; then  
  ConfigureAB ""

elif [ $REPONSEbff -ge $PremierBFF ] && [ $REPONSEbff -lt $DernierBFF ] ; then  

  j=0
  for i in $InstallationsBFourFree ; do
    if [ $j -eq $rbff ] ; then k="$i" ; fi
    j=`expr $j + 1`
  done

  ConfigureBFF "$k"
#  ConfigureBFF "${InstallationsBFourFree[$rbff]}"

elif [ $REPONSEbff -eq $DernierBFF ] ; then  
  ConfigureBFF ""

else 
  MessageErreur "" "Wrong answer. Integer between 1 and `expr 1 + $DernierBFF` expected."
fi
#Tableau accessible  partir de la case 0 de la manire suivante 
#
#echo "${InstallationsBFourFree[0]}"
# Longueur du tableau InstallationsBFourFree : 
#echo "taille : ${#InstallationsBFourFree[*]}"
#
# Rcupration des informations du prouveur
#====================================================================





    







#====================================================================
# Rcupration du nom du dossier de travail par dfaut
# ----------------------------------------------------
#
echo ""
echo "Info : "
echo "   The name of the working folder is the name used by default by GeneSyst"
echo "   to create a directory in which it will generates all intermediate files."
PoseQuestion "Name of the working folder" "TransitionsComputation"
DossierTravail=$REPONSE
#
# FIN Rcupration du nom du dossier de travail par dfaut
#====================================================================
 






#====================================================================
# Rcupration du nom du projet de base
# -------------------------------------
#
echo ""
echo "Info : "
echo "   This name is the default one used by GeneSyst to create a temporary "
echo "   project under the atelierB."
echo "   This name is restricted to 23 characters long."
PoseQuestion "Name of the project" "TransitionsComputationTmpxxx"
ProjetTravail=$REPONSE
#
# FIN Rcupration du nom du projet de base
#====================================================================








#====================================================================
# Rcupration du nom du dossier de rsultat par dfaut
# ----------------------------------------------------
#
echo ""
echo "Info : "
echo "   Name of the directory in which GeneSyst will generates resulting files."
PoseQuestion "Name of the result directory" "Result"
DossierResultat=$REPONSE
#
# FIN Rcupration du nom du dossier de rsultat par dfaut
#====================================================================
 




#====================================================================
# Configuration de l'interface avec l'application DOT
# ---------------------------------------------------
#
echo ""
echo "Info : "
echo "   The 'dot' application, provided by the 'GraphViz' package, is used for"
echo "   statecharts generation."
R=`which dot`
if [ `echo $R | grep "/dot"` ] && [ ! `echo $R | grep "not found"` ]; then
  PoseQuestion "Path to 'dot'" "$R"
else 
  PoseQuestion "Path to 'dot'" ""
fi
CheminDot=$REPONSE
if [ -n "$CheminDot" ] ; then
  if [ ! -x $CheminDot ] || [ ! `echo $CheminDot | grep  '/dot$'` ] ; then 
    MessageErreur "" "Wrong path to dot application" 
  fi
fi
#
# FIN de Configuration de l'interface avec l'application DOT
#====================================================================






#====================================================================
# Choix du dossier d'installation du script
echo ""
echo "Info : "
echo "   It is recommended that the installation folder be present in the "
echo "   \$PATH environnement variable."
PoseQuestion "In which folder would you install the script used to call GeneSyst" "$HOME/bin"
while [ ! -d "$REPONSE" ] 
do
  echo "Wrong filder name (Folder not found or this path point out a classical file)."
  PoseQuestion "In which folder would you install the script used to call GeneSyst" "$HOME/bin"
done
DossierInstallationScript=$REPONSE
#
# FIN Choix du dossier d'installation du script
#====================================================================








#====================================================================
# Vrification avant gnration
# -----------------------------
#
echo ""
echo ""
echo "Sumarize:"
echo "   Prover:"
echo "      bdb:                          '$DossierBDB'"
echo "      bbatch:                       '$Adressebbatch'"
echo "      configuration:                '$FichierConfig'"

echo "   Working folder name:             '$DossierTravail'"
echo "   Working project name:            '$ProjetTravail'"
echo "   Result folder name:              '$DossierResultat'"  
echo "   Call script folder installation: '$DossierInstallationScript'"  

echo -n "   Dot application:               "
if [ -n "$CheminDot" ] ; then 
  echo "'$CheminDot'"
else
  echo " not setted up or not installed"
fi

PoseQuestion "Do you accept these information" "Y"
if [ $REPONSE != "y" ] && [ $REPONSE != "Y" ] ; then MessageErreur "" "Configuration aborded by user." ; fi
#
# FIN Vrification avant gnration
#====================================================================







#====================================================================
# Gnration du script d'appel
echo '#!/bin/bash' > $DossierInstallationScript/GeneSyst
echo '###############' >> $DossierInstallationScript/GeneSyst
echo '# Script gnr automatiquement par l''intallation de GeneSyst' >> $DossierInstallationScript/GeneSyst
echo '###############' >> $DossierInstallationScript/GeneSyst
echo '' >> $DossierInstallationScript/GeneSyst
echo "JARPATH=`pwd`/GeneSyst.jar" >> $DossierInstallationScript/GeneSyst
echo 'java -classpath ${JARPATH} geneSyst/GUI_V2/GeneSystGUI' >> $DossierInstallationScript/GeneSyst
chmod +x "$DossierInstallationScript/GeneSyst"
#
echo '#!/bin/bash' > $DossierInstallationScript/GeneSyst.old_gui
echo '###############' >> $DossierInstallationScript/GeneSyst.old_gui
echo '# Script gnr automatiquement par l''intallation de GeneSyst' >> $DossierInstallationScript/GeneSyst.old_gui
echo '###############' >> $DossierInstallationScript/GeneSyst.old_gui
echo '' >> $DossierInstallationScript/GeneSyst.old_gui
echo "JARPATH=`pwd`/GeneSyst.jar" >> $DossierInstallationScript/GeneSyst.old_gui
echo 'java -classpath ${JARPATH} geneSyst/GUI/AppliGene' >> $DossierInstallationScript/GeneSyst.old_gui
chmod +x "$DossierInstallationScript/GeneSyst.old_gui"
#
echo '#!/bin/bash' > $DossierInstallationScript/GeneSyst-tui
echo '###############' >> $DossierInstallationScript/GeneSyst-tui
echo '# Script gnr automatiquement par l''intallation de GeneSyst' >> $DossierInstallationScript/GeneSyst-tui
echo '###############' >> $DossierInstallationScript/GeneSyst-tui
echo '' >> $DossierInstallationScript/GeneSyst-tui
echo "#GSPATH=`pwd`/Class" >> $DossierInstallationScript/GeneSyst-tui
echo '#java -classpath $GSPATH:$GSPATH/GUI:$GSPATH/GRAPPA/att/grappa/:$GSPATH/GRAPPA/java_cup/runtime/:$CLASSPATH geneSyst $*' >> $DossierInstallationScript/GeneSyst-tui
echo "JARPATH=`pwd`/GeneSyst.jar" >> $DossierInstallationScript/GeneSyst-tui
echo 'java -jar ${JARPATH} $*' >> $DossierInstallationScript/GeneSyst-tui
chmod +x "$DossierInstallationScript/GeneSyst-tui"
#
# FIN Gnration du script d'appel
#====================================================================





#====================================================================
# Gnration du fichier de configuration
# --------------------------------------
#
TMPDIR=geneSyst
JAVAFILE=${TMPDIR}/ConfigurationGeneSyst.java
CLASSFILE=${TMPDIR}/ConfigurationGeneSyst.class

mkdir ${TMPDIR}
echo ""
echo "Gnration et compilation du fichier '${JAVAFILE}'"
if [ -f "${JAVAFILE}" ] ; then mv "${JAVAFILE}" "${JAVAFILE}.svg" ; fi
if [ -f "${CLASSFILE}" ] ; then rm "${CLASSFILE}" ; fi
echo "/*********************************************************************/" > ${JAVAFILE}
echo "/*  Fichier genere automatiquement par le script d'installation de   */" >> ${JAVAFILE}
echo "/*                              GeneSyst                             */" >> ${JAVAFILE}
echo "/*********************************************************************/" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo "package geneSyst;" >> ${JAVAFILE}
echo "import java.util.ArrayList;" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo "public class ConfigurationGeneSyst { " >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo " /** Adresse du dossier BDB de l'atelier */"  >> ${JAVAFILE}
echo "  public static String AdresseDossierBDB=\"$DossierBDB\";"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}


echo "  /** Methode d'appel du prouveur */"  >> ${JAVAFILE}
echo "   public static String AppelAtelierB=\"$Adressebbatch -r=$FichierConfig\";"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}


echo "// /h3/nephtys/lsr/vasco/atelierb/AB/press/bdb/          -> Anchieta"  >> ${JAVAFILE}
echo "// /usr/local/src/atelierB-beta/version3.6/AB/press/bdb/ -> Horus"  >> ${JAVAFILE}
echo "// /usr/local/src/atelierB/version3.6/AB/press/bdb/      -> Bastet"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo " /** Nom de base du projet */"  >> ${JAVAFILE}
echo "  public static String NomProjetDeBase=\"$ProjetTravail\";"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo " /** Nom de base du dossier de travail */"  >> ${JAVAFILE}
echo "  public static String NomDossierDeBase=\"$DossierTravail\";"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo " /** Nom du dossier resultats */"  >> ${JAVAFILE}
echo "  public static String NomDossierResultat = \"$DossierResultat\";"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}


# Prfrences imposes

echo " /** Nom du fichier de traces */"  >> ${JAVAFILE}
echo "  public static String NomFichierTraces = \"TraceGenesyst.log\";"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo " /** Nom du chemin du dot */" >> ${JAVAFILE}
echo "  public static String PathDot =\"/usr/bin/dot\";" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}
  
echo " /** Nom du fichier au format html */" >> ${JAVAFILE}
echo "  public static String NomFichierHtml =\"index.html\";" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}
  
echo " /** Variable indiquant le choix par defaut quand aux preuves existentielles.**/" >> ${JAVAFILE}
echo "  public static boolean Cst_FaireExistentielle = false;" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}



echo " /** Nombre de formats de sortie supportes par GeneSyst.**/" >> ${JAVAFILE}
echo "   public static int NbFormatsSortie=3;" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

if [ -z $CheminDot ] ; then 
  echo " /** tableau memorisant quels formats de sortie peuvent etre utilises (la " >> ${JAVAFILE}
  echo "   * limitation etant les applications externes).**/" >> ${JAVAFILE}
  echo "  public static boolean[] TabFormatsSortiePossibles={false,false,true};" >> ${JAVAFILE}
  echo "" >> ${JAVAFILE}

  echo " /** tableau memorisant les formats de sortie demande par l'utilisateur.**/" >> ${JAVAFILE}
  echo "  public static boolean[] TabFormatsSortie={false,false,true};" >> ${JAVAFILE}
else
  echo " /** tableau memorisant quels formats de sortie peuvent etre utilises (la " >> ${JAVAFILE}
  echo "   * limitation etant les applications externes).**/" >> ${JAVAFILE}
  echo "  public static boolean[] TabFormatsSortiePossibles={true,true,true};" >> ${JAVAFILE}
  echo "" >> ${JAVAFILE}

  echo " /** tableau memorisant les formats de sortie demandes par l'utilisateur.**/" >> ${JAVAFILE}
  echo "  public static boolean[] TabFormatsSortie={true,true,false};" >> ${JAVAFILE}
fi
echo "" >> ${JAVAFILE}
  
echo " /**Definition des constantes correspondant aux formats*/" >> ${JAVAFILE}
echo "  public static int FormatDot  = 0;" >> ${JAVAFILE}
echo "  public static int FormatHtml = 1;" >> ${JAVAFILE}
echo "  public static int FormatGxl  = 2;" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}


echo " /**Definition des tactiques interactives*/" >> ${JAVAFILE}
echo "  public static ArrayList<ArrayList<String>> TactiquesUtilisateur=null;" >> ${JAVAFILE}
echo "  static public void initTactiquesInteractives() {" >> ${JAVAFILE}
echo "    ArrayList<ArrayList<String>> Tu=new ArrayList<ArrayList<String>>();" >> ${JAVAFILE}
echo "    ArrayList<String> tmp;" >> ${JAVAFILE}
echo "" >> ${JAVAFILE}

echo "    Tu.add(tmp=new ArrayList<String>());" >> ${JAVAFILE}
echo "    tmp.add(\"dd\");" >> ${JAVAFILE}
echo "    tmp.add(\"pp(rp.0)\");" >> ${JAVAFILE}

echo "    Tu.add(tmp=new ArrayList<String>());" >> ${JAVAFILE}
echo "    tmp.add(\"pp(rp.0)\");" >> ${JAVAFILE}

echo "    Tu.add(tmp=new ArrayList<String>());" >> ${JAVAFILE}
echo "    tmp.add(\"dd\");" >> ${JAVAFILE}
echo "    tmp.add(\"pp(rp.1)\");" >> ${JAVAFILE}

echo "    Tu.add(tmp=new ArrayList<String>());" >> ${JAVAFILE}
echo "    tmp.add(\"dd\");" >> ${JAVAFILE}
echo "    tmp.add(\"pp(rp.2)\");" >> ${JAVAFILE}

echo "    Tu.add(tmp=new ArrayList<String>());" >> ${JAVAFILE}
echo "    tmp.add(\"pp(rp.1)\");" >> ${JAVAFILE}

echo "" >> ${JAVAFILE}
echo "    TactiquesUtilisateur=Tu;" >> ${JAVAFILE}
echo "  }"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}



echo "}"  >> ${JAVAFILE}
echo "" >> ${JAVAFILE}
#
# Compilation
javac ${JAVAFILE}
jar uf GeneSyst.jar ${JAVAFILE} ${CLASSFILE}
rm ${JAVAFILE}
rm ${CLASSFILE}
rmdir ${TMPDIR}
#
#
# Gnration du fichier de configuration
#====================================================================






echo ""
echo "Installation finished"
echo ""
echo "Info :"
echo "   All provided information are in the file Class/ConfigurationGeneSyst.java."
echo "   To modify it, you can directly edit this file, or re-run this script."
echo ""
echo "   For all other information : "
echo "                nicolas.stouls@insa-lyon.fr"
echo ""
echo "=============================================================================="
echo "Note: "
echo "-----"
echo "  If you use a windows manager that does not force windows to be refreshed"
echo "  i.e. Beryl or compiz), then add the following line to your .bashrc file:"
echo ""
echo "            export AWT_TOOLKIT=MToolkit"
echo ""
echo "=============================================================================="
echo ""

